@@ -21,6 +21,7 @@ import datetime
 import os
 import sys
 import time
+from pathlib import Path
 from pprint import pformat
 
 from dateutil import parser as date_parser
@@ -262,11 +263,18 @@ def add_ocp_parser_args(parser):
 def add_oci_parser_args(parser):
     """Add OCI sub-parser args."""
     parser.add_argument(
-        "--oci-report-type",
-        metavar="OCI_REPORT_TYPE",
-        dest="oci_report_type",
+        "--oci-bucket-name",
+        metavar="BUCKET_NAME",
+        dest="oci_bucket_name",
         required=False,
-        help="Type of report to generate.",
+        help="OCI storage bucket where to upload generated reports.",
+    )
+    parser.add_argument(
+        "--oci-local-bucket",
+        metavar="OCI_LOCAL_BUCKET",
+        dest="oci_local_bucket",
+        required=False,
+        help="Local bucket or path where to upload generated reports.",
     )
 
 
@@ -534,7 +542,7 @@ def _validate_gcp_arguments(parser, options):
 
 
 def _validate_oci_arguments(parser, options):
-    """Validate aws argument combination.
+    """Validate oci argument combination.
 
     Args:
         parser (Object): ArgParser parser.
@@ -543,7 +551,22 @@ def _validate_oci_arguments(parser, options):
         (ParserError): If combination is invalid.
 
     """
-    return True
+    is_args_valid = False
+    local_bucket = options.get("oci_local_bucket")
+    bucket_name = options.get("oci_bucket_name")
+    config_file = os.environ.get("OCI_CONFIG_FILE")
+
+    if (not bucket_name) or (bucket_name and config_file and Path(config_file).exists()) or local_bucket:
+        is_args_valid = True
+    else:
+        msg = (
+            f"\n\t--oci-bucket-name {bucket_name} was supplied as an argument\n"
+            "\tbut a config file path is not set in your environment or does not exist locally."
+        )
+        msg = msg.format("--oci-bucket-name")
+        parser.error(msg)
+
+    return is_args_valid
 
 
 def _validate_provider_inputs(parser, options):
