@@ -52,7 +52,7 @@ class VMGenerator(AzureGenerator):
         },
     )
 
-    def __init__(self, start_date, end_date, account_info, attributes=None):
+    def __init__(self, start_date, end_date, currency, account_info, attributes=None):
         """Initialize the data transfer generator."""
         self._service_name = "Virtual Machines"
-        super().__init__(start_date, end_date, account_info, attributes)
+        super().__init__(start_date, end_date, currency, account_info, attributes)
