@@ -33,6 +33,8 @@ class ComputeEngineGenerator(GCPGenerator):
         ("D0CC-50DF-59D2", "Network Inter Zone Ingress", "bytes", "gibibyte"),
         ("F449-33EC-A5EF", "E2 Instance Ram running in Americas", "byte-seconds", "gibibyte hour"),
         ("CD20-B4CA-0F7C", "Licensing Fee for Debian 10 Buster (RAM cost)", "byte-seconds", "gibiyte hour"),
+        ("236F-83FC-852C", "Licensing Fee for RedHat Enterprise Linux 8 (RAM cost)", "byte-seconds", "gibiyte hour"),
+        ("8C61-80B1-C43A", "Licensing Fee for RedHat Enterprise Linux 8 on VM with 1 to 4 VCPU", "seconds", "hour"),
         ("6B8F-E63D-832B", "Network Internet Egress from Americas to APAC", "bytes", "gibibyte"),
         ("DFA5-B5C6-36D6", "Network Internet Egress from Americas to EMEA", "bytes", "gibibyte"),
         ("9DE9-9092-B3BC", "Network Internet Egress from Americas to China", "bytes", "gibibyte"),
